# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentDisputeSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'SimpleAmount',
        'buyer_username': 'str',
        'closed_date': 'str',
        'open_date': 'str',
        'order_id': 'str',
        'payment_dispute_id': 'str',
        'payment_dispute_status': 'str',
        'reason': 'str',
        'respond_by_date': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'buyer_username': 'buyerUsername',
        'closed_date': 'closedDate',
        'open_date': 'openDate',
        'order_id': 'orderId',
        'payment_dispute_id': 'paymentDisputeId',
        'payment_dispute_status': 'paymentDisputeStatus',
        'reason': 'reason',
        'respond_by_date': 'respondByDate'
    }

    def __init__(self, amount=None, buyer_username=None, closed_date=None, open_date=None, order_id=None, payment_dispute_id=None, payment_dispute_status=None, reason=None, respond_by_date=None):  # noqa: E501
        """PaymentDisputeSummary - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._buyer_username = None
        self._closed_date = None
        self._open_date = None
        self._order_id = None
        self._payment_dispute_id = None
        self._payment_dispute_status = None
        self._reason = None
        self._respond_by_date = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if buyer_username is not None:
            self.buyer_username = buyer_username
        if closed_date is not None:
            self.closed_date = closed_date
        if open_date is not None:
            self.open_date = open_date
        if order_id is not None:
            self.order_id = order_id
        if payment_dispute_id is not None:
            self.payment_dispute_id = payment_dispute_id
        if payment_dispute_status is not None:
            self.payment_dispute_status = payment_dispute_status
        if reason is not None:
            self.reason = reason
        if respond_by_date is not None:
            self.respond_by_date = respond_by_date

    @property
    def amount(self):
        """Gets the amount of this PaymentDisputeSummary.  # noqa: E501


        :return: The amount of this PaymentDisputeSummary.  # noqa: E501
        :rtype: SimpleAmount
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentDisputeSummary.


        :param amount: The amount of this PaymentDisputeSummary.  # noqa: E501
        :type: SimpleAmount
        """

        self._amount = amount

    @property
    def buyer_username(self):
        """Gets the buyer_username of this PaymentDisputeSummary.  # noqa: E501

        This is the buyer's eBay user ID. This field is returned for all payment disputes returned in the response.  # noqa: E501

        :return: The buyer_username of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._buyer_username

    @buyer_username.setter
    def buyer_username(self, buyer_username):
        """Sets the buyer_username of this PaymentDisputeSummary.

        This is the buyer's eBay user ID. This field is returned for all payment disputes returned in the response.  # noqa: E501

        :param buyer_username: The buyer_username of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._buyer_username = buyer_username

    @property
    def closed_date(self):
        """Gets the closed_date of this PaymentDisputeSummary.  # noqa: E501

        The timestamp in this field shows the date/time when the payment dispute was closed, so this field is only returned for payment disputes in the <code>CLOSED</code> state.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The closed_date of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._closed_date

    @closed_date.setter
    def closed_date(self, closed_date):
        """Sets the closed_date of this PaymentDisputeSummary.

        The timestamp in this field shows the date/time when the payment dispute was closed, so this field is only returned for payment disputes in the <code>CLOSED</code> state.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param closed_date: The closed_date of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._closed_date = closed_date

    @property
    def open_date(self):
        """Gets the open_date of this PaymentDisputeSummary.  # noqa: E501

        The timestamp in this field shows the date/time when the payment dispute was opened. This field is returned for payment disputes in all states.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The open_date of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._open_date

    @open_date.setter
    def open_date(self, open_date):
        """Sets the open_date of this PaymentDisputeSummary.

        The timestamp in this field shows the date/time when the payment dispute was opened. This field is returned for payment disputes in all states.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param open_date: The open_date of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._open_date = open_date

    @property
    def order_id(self):
        """Gets the order_id of this PaymentDisputeSummary.  # noqa: E501

        This is the unique identifier of the order involved in the payment dispute.  # noqa: E501

        :return: The order_id of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this PaymentDisputeSummary.

        This is the unique identifier of the order involved in the payment dispute.  # noqa: E501

        :param order_id: The order_id of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_dispute_id(self):
        """Gets the payment_dispute_id of this PaymentDisputeSummary.  # noqa: E501

        This is the unique identifier of the payment dispute. This identifier is automatically created by eBay once the payment dispute comes into the eBay system. This identifier is passed in at the end of the <strong>getPaymentDispute</strong> call URI to retrieve a specific payment dispute. The <strong>getPaymentDispute</strong> method returns more details about a payment dispute than the <strong>getPaymentDisputeSummaries</strong> method.  # noqa: E501

        :return: The payment_dispute_id of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._payment_dispute_id

    @payment_dispute_id.setter
    def payment_dispute_id(self, payment_dispute_id):
        """Sets the payment_dispute_id of this PaymentDisputeSummary.

        This is the unique identifier of the payment dispute. This identifier is automatically created by eBay once the payment dispute comes into the eBay system. This identifier is passed in at the end of the <strong>getPaymentDispute</strong> call URI to retrieve a specific payment dispute. The <strong>getPaymentDispute</strong> method returns more details about a payment dispute than the <strong>getPaymentDisputeSummaries</strong> method.  # noqa: E501

        :param payment_dispute_id: The payment_dispute_id of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._payment_dispute_id = payment_dispute_id

    @property
    def payment_dispute_status(self):
        """Gets the payment_dispute_status of this PaymentDisputeSummary.  # noqa: E501

        The enumeration value in this field gives the current status of the payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeStateEnum'>eBay API documentation</a>  # noqa: E501

        :return: The payment_dispute_status of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._payment_dispute_status

    @payment_dispute_status.setter
    def payment_dispute_status(self, payment_dispute_status):
        """Sets the payment_dispute_status of this PaymentDisputeSummary.

        The enumeration value in this field gives the current status of the payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeStateEnum'>eBay API documentation</a>  # noqa: E501

        :param payment_dispute_status: The payment_dispute_status of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._payment_dispute_status = payment_dispute_status

    @property
    def reason(self):
        """Gets the reason of this PaymentDisputeSummary.  # noqa: E501

        The enumeration value in this field gives the reason why the buyer initiated the payment dispute. See <strong>DisputeReasonEnum</strong> type for a description of the supported reasons that buyers can give for initiating a payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeReasonEnum'>eBay API documentation</a>  # noqa: E501

        :return: The reason of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this PaymentDisputeSummary.

        The enumeration value in this field gives the reason why the buyer initiated the payment dispute. See <strong>DisputeReasonEnum</strong> type for a description of the supported reasons that buyers can give for initiating a payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeReasonEnum'>eBay API documentation</a>  # noqa: E501

        :param reason: The reason of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def respond_by_date(self):
        """Gets the respond_by_date of this PaymentDisputeSummary.  # noqa: E501

        The timestamp in this field shows the date/time when the seller must response to a payment dispute, so this field is only returned for payment disputes in the <code>ACTION_NEEDED</code> state. For payment disputes that require action by the seller, that same seller must call <strong>getPaymentDispute</strong> to see the next action(s) that they can take against the payment dispute.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The respond_by_date of this PaymentDisputeSummary.  # noqa: E501
        :rtype: str
        """
        return self._respond_by_date

    @respond_by_date.setter
    def respond_by_date(self, respond_by_date):
        """Sets the respond_by_date of this PaymentDisputeSummary.

        The timestamp in this field shows the date/time when the seller must response to a payment dispute, so this field is only returned for payment disputes in the <code>ACTION_NEEDED</code> state. For payment disputes that require action by the seller, that same seller must call <strong>getPaymentDispute</strong> to see the next action(s) that they can take against the payment dispute.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param respond_by_date: The respond_by_date of this PaymentDisputeSummary.  # noqa: E501
        :type: str
        """

        self._respond_by_date = respond_by_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentDisputeSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentDisputeSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Account API

    The <b>Account API</b> gives sellers the ability to configure their eBay seller accounts, including the seller's policies (eBay business policies and seller-defined custom policies), opt in and out of eBay seller programs, configure sales tax tables, and get account information.  <br/><br/>For details on the availability of the methods in this API, see <a href=\"/api-docs/sell/account/overview.html#requirements\">Account API requirements and restrictions</a>.  # noqa: E501

    OpenAPI spec version: v1.9.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ...sell_account.api_client import ApiClient


class KycApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_kyc(self, **kwargs):  # noqa: E501
        """get_kyc  # noqa: E501

        <span class=\"tablenote\"><b>Note:</b>This method was originally created to see which onboarding requirements were still pending for sellers being onboarded for eBay managed payments, but now that all seller accounts are onboarded globally, this method should now just returne an empty payload with a <code>204 No Content</code> HTTP status code. </span>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_kyc(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: KycResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_kyc_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_kyc_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_kyc_with_http_info(self, **kwargs):  # noqa: E501
        """get_kyc  # noqa: E501

        <span class=\"tablenote\"><b>Note:</b>This method was originally created to see which onboarding requirements were still pending for sellers being onboarded for eBay managed payments, but now that all seller accounts are onboarded globally, this method should now just returne an empty payload with a <code>204 No Content</code> HTTP status code. </span>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_kyc_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: KycResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_kyc" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_auth']  # noqa: E501

        return self.api_client.call_api(
            '/kyc', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='KycResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ...buy_order.api.guest_checkout_session_api import GuestCheckoutSessionApi
from ...buy_order.api.guest_purchase_order_api import GuestPurchaseOrderApi



# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Amount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'converted_from_currency': 'str',
        'converted_from_value': 'str',
        'currency': 'str',
        'value': 'str'
    }

    attribute_map = {
        'converted_from_currency': 'convertedFromCurrency',
        'converted_from_value': 'convertedFromValue',
        'currency': 'currency',
        'value': 'value'
    }

    def __init__(self, converted_from_currency=None, converted_from_value=None, currency=None, value=None):  # noqa: E501
        """Amount - a model defined in Swagger"""  # noqa: E501
        self._converted_from_currency = None
        self._converted_from_value = None
        self._currency = None
        self._value = None
        self.discriminator = None
        if converted_from_currency is not None:
            self.converted_from_currency = converted_from_currency
        if converted_from_value is not None:
            self.converted_from_value = converted_from_value
        if currency is not None:
            self.currency = currency
        if value is not None:
            self.value = value

    @property
    def converted_from_currency(self):
        """Gets the converted_from_currency of this Amount.  # noqa: E501

        A three-letter ISO 4217 code that indicates the currency of the amount in the <b>convertedFromValue</b> field. This value is required or returned only if currency conversion/localization is required, and represents the pre-conversion currency. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/ba:CurrencyCodeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The converted_from_currency of this Amount.  # noqa: E501
        :rtype: str
        """
        return self._converted_from_currency

    @converted_from_currency.setter
    def converted_from_currency(self, converted_from_currency):
        """Sets the converted_from_currency of this Amount.

        A three-letter ISO 4217 code that indicates the currency of the amount in the <b>convertedFromValue</b> field. This value is required or returned only if currency conversion/localization is required, and represents the pre-conversion currency. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/ba:CurrencyCodeEnum'>eBay API documentation</a>  # noqa: E501

        :param converted_from_currency: The converted_from_currency of this Amount.  # noqa: E501
        :type: str
        """

        self._converted_from_currency = converted_from_currency

    @property
    def converted_from_value(self):
        """Gets the converted_from_value of this Amount.  # noqa: E501

        The monetary amount before any conversion is performed, in the currency specified by the <b>convertedFromCurrency</b> field. This value is required or returned only if currency conversion/localization is required. The <b>value</b> field contains the converted amount of this value, in the currency specified by the <b>currency</b> field.  # noqa: E501

        :return: The converted_from_value of this Amount.  # noqa: E501
        :rtype: str
        """
        return self._converted_from_value

    @converted_from_value.setter
    def converted_from_value(self, converted_from_value):
        """Sets the converted_from_value of this Amount.

        The monetary amount before any conversion is performed, in the currency specified by the <b>convertedFromCurrency</b> field. This value is required or returned only if currency conversion/localization is required. The <b>value</b> field contains the converted amount of this value, in the currency specified by the <b>currency</b> field.  # noqa: E501

        :param converted_from_value: The converted_from_value of this Amount.  # noqa: E501
        :type: str
        """

        self._converted_from_value = converted_from_value

    @property
    def currency(self):
        """Gets the currency of this Amount.  # noqa: E501

        A three-letter ISO 4217 code that indicates the currency of the amount in the <b>value</b> field. If currency conversion/localization is required, this is the post-conversion currency of the amount in the <b>value</b> field.<br /><br /><b>Default:</b> The default currency of the eBay marketplace that hosts the listing. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/ba:CurrencyCodeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The currency of this Amount.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Amount.

        A three-letter ISO 4217 code that indicates the currency of the amount in the <b>value</b> field. If currency conversion/localization is required, this is the post-conversion currency of the amount in the <b>value</b> field.<br /><br /><b>Default:</b> The default currency of the eBay marketplace that hosts the listing. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/ba:CurrencyCodeEnum'>eBay API documentation</a>  # noqa: E501

        :param currency: The currency of this Amount.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def value(self):
        """Gets the value of this Amount.  # noqa: E501

        The monetary amount, in the currency specified by the <b>currency</b> field. If currency conversion/localization is required, this value is the converted amount, and the <b>convertedFromValue</b> field contains the amount in the original currency.  <br><br><i>Required in</i> the <b>amount</b> type.  # noqa: E501

        :return: The value of this Amount.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Amount.

        The monetary amount, in the currency specified by the <b>currency</b> field. If currency conversion/localization is required, this value is the converted amount, and the <b>convertedFromValue</b> field contains the amount in the original currency.  <br><br><i>Required in</i> the <b>amount</b> type.  # noqa: E501

        :param value: The value of this Amount.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Amount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Amount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
     Seller Service Metrics API 

    The <i>Analytics API</i> provides data and information about a seller and their eBay business.  <br><br>The resources and methods in this API let sellers review information on their listing performance, metrics on their customer service performance, and details on their eBay seller performance rating.  <br><br>The three resources in the Analytics API provide the following data and information: <ul><li><b>Customer Service Metric</b> &ndash; Returns data on a seller's customer service performance as compared to other seller's in the same peer group.</li> <li><b>Traffic Report</b> &ndash; Returns data that shows how buyers are engaging with a seller's listings.</li> <li><b>Seller Standards Profile</b> &ndash; Returns data pertaining to a seller's performance rating.</li></ul> Sellers can use the data and information returned by the various Analytics API methods to determine where they can make improvements to increase sales and how they might improve their seller status as viewed by eBay buyers.  <br><br>For details on using this API, see <a href=\"/api-docs/sell/static/performance/analyzing-performance.html\" title=\"Selling Integration Guide\">Analyzing seller performance</a>.  # noqa: E501

    OpenAPI spec version: 1.2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MetricBenchmark(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'adjustment': 'str',
        'basis': 'str',
        'metadata': 'BenchmarkMetadata',
        'rating': 'str'
    }

    attribute_map = {
        'adjustment': 'adjustment',
        'basis': 'basis',
        'metadata': 'metadata',
        'rating': 'rating'
    }

    def __init__(self, adjustment=None, basis=None, metadata=None, rating=None):  # noqa: E501
        """MetricBenchmark - a model defined in Swagger"""  # noqa: E501
        self._adjustment = None
        self._basis = None
        self._metadata = None
        self._rating = None
        self.discriminator = None
        if adjustment is not None:
            self.adjustment = adjustment
        if basis is not None:
            self.basis = basis
        if metadata is not None:
            self.metadata = metadata
        if rating is not None:
            self.rating = rating

    @property
    def adjustment(self):
        """Gets the adjustment of this MetricBenchmark.  # noqa: E501

        If this field is present, it indicates that the rating given to the seller was &quot;adjusted&quot; for one reason or another. If eBay determines that the normal rating of a seller is impacted by circumstances beyond their control, they can issue an override to adjust the rating given to the seller. For implementation help, refer to <a href='https://developer.ebay.com/devzone/rest/api-ref/analytics/types/RatingAdjustmentTypeEnum.html'>eBay API documentation</a>  # noqa: E501

        :return: The adjustment of this MetricBenchmark.  # noqa: E501
        :rtype: str
        """
        return self._adjustment

    @adjustment.setter
    def adjustment(self, adjustment):
        """Sets the adjustment of this MetricBenchmark.

        If this field is present, it indicates that the rating given to the seller was &quot;adjusted&quot; for one reason or another. If eBay determines that the normal rating of a seller is impacted by circumstances beyond their control, they can issue an override to adjust the rating given to the seller. For implementation help, refer to <a href='https://developer.ebay.com/devzone/rest/api-ref/analytics/types/RatingAdjustmentTypeEnum.html'>eBay API documentation</a>  # noqa: E501

        :param adjustment: The adjustment of this MetricBenchmark.  # noqa: E501
        :type: str
        """

        self._adjustment = adjustment

    @property
    def basis(self):
        """Gets the basis of this MetricBenchmark.  # noqa: E501

        This field returns the &quot;basis&quot; by which the benchmark is calculated for the customer service metric type. Currently, the only supported basis is PEER_BENCHMARK. For implementation help, refer to <a href='https://developer.ebay.com/devzone/rest/api-ref/analytics/types/BenchmarkTypeEnum.html'>eBay API documentation</a>  # noqa: E501

        :return: The basis of this MetricBenchmark.  # noqa: E501
        :rtype: str
        """
        return self._basis

    @basis.setter
    def basis(self, basis):
        """Sets the basis of this MetricBenchmark.

        This field returns the &quot;basis&quot; by which the benchmark is calculated for the customer service metric type. Currently, the only supported basis is PEER_BENCHMARK. For implementation help, refer to <a href='https://developer.ebay.com/devzone/rest/api-ref/analytics/types/BenchmarkTypeEnum.html'>eBay API documentation</a>  # noqa: E501

        :param basis: The basis of this MetricBenchmark.  # noqa: E501
        :type: str
        """

        self._basis = basis

    @property
    def metadata(self):
        """Gets the metadata of this MetricBenchmark.  # noqa: E501


        :return: The metadata of this MetricBenchmark.  # noqa: E501
        :rtype: BenchmarkMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this MetricBenchmark.


        :param metadata: The metadata of this MetricBenchmark.  # noqa: E501
        :type: BenchmarkMetadata
        """

        self._metadata = metadata

    @property
    def rating(self):
        """Gets the rating of this MetricBenchmark.  # noqa: E501

        This field returns seller's rating for the customer service metric. The rating is set to a value that equals the relative deviation between the seller's metric value and the benchmark value for the customer service metric. Deviation values range from LOW to VERY HIGH, and the lower the deviation, the better the seller rating. For implementation help, refer to <a href='https://developer.ebay.com/devzone/rest/api-ref/analytics/types/RatingTypeEnum.html'>eBay API documentation</a>  # noqa: E501

        :return: The rating of this MetricBenchmark.  # noqa: E501
        :rtype: str
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this MetricBenchmark.

        This field returns seller's rating for the customer service metric. The rating is set to a value that equals the relative deviation between the seller's metric value and the benchmark value for the customer service metric. Deviation values range from LOW to VERY HIGH, and the lower the deviation, the better the seller rating. For implementation help, refer to <a href='https://developer.ebay.com/devzone/rest/api-ref/analytics/types/RatingTypeEnum.html'>eBay API documentation</a>  # noqa: E501

        :param rating: The rating of this MetricBenchmark.  # noqa: E501
        :type: str
        """

        self._rating = rating

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetricBenchmark, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricBenchmark):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Error(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'domain': 'str',
        'error_id': 'int',
        'input_ref_ids': 'list[str]',
        'long_message': 'str',
        'message': 'str',
        'output_ref_ids': 'list[str]',
        'parameters': 'list[ErrorParameter]',
        'subdomain': 'str'
    }

    attribute_map = {
        'category': 'category',
        'domain': 'domain',
        'error_id': 'errorId',
        'input_ref_ids': 'inputRefIds',
        'long_message': 'longMessage',
        'message': 'message',
        'output_ref_ids': 'outputRefIds',
        'parameters': 'parameters',
        'subdomain': 'subdomain'
    }

    def __init__(self, category=None, domain=None, error_id=None, input_ref_ids=None, long_message=None, message=None, output_ref_ids=None, parameters=None, subdomain=None):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501
        self._category = None
        self._domain = None
        self._error_id = None
        self._input_ref_ids = None
        self._long_message = None
        self._message = None
        self._output_ref_ids = None
        self._parameters = None
        self._subdomain = None
        self.discriminator = None
        if category is not None:
            self.category = category
        if domain is not None:
            self.domain = domain
        if error_id is not None:
            self.error_id = error_id
        if input_ref_ids is not None:
            self.input_ref_ids = input_ref_ids
        if long_message is not None:
            self.long_message = long_message
        if message is not None:
            self.message = message
        if output_ref_ids is not None:
            self.output_ref_ids = output_ref_ids
        if parameters is not None:
            self.parameters = parameters
        if subdomain is not None:
            self.subdomain = subdomain

    @property
    def category(self):
        """Gets the category of this Error.  # noqa: E501

        The context or source of this error or warning.  # noqa: E501

        :return: The category of this Error.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Error.

        The context or source of this error or warning.  # noqa: E501

        :param category: The category of this Error.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def domain(self):
        """Gets the domain of this Error.  # noqa: E501

        The name of the domain containing the service or application. For example, <code>sell</code> is a domain.  # noqa: E501

        :return: The domain of this Error.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this Error.

        The name of the domain containing the service or application. For example, <code>sell</code> is a domain.  # noqa: E501

        :param domain: The domain of this Error.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def error_id(self):
        """Gets the error_id of this Error.  # noqa: E501

        A positive integer that uniquely identifies the specific error condition that occurred. Your application can use these values as error code identifiers in your customized error-handling algorithms.  # noqa: E501

        :return: The error_id of this Error.  # noqa: E501
        :rtype: int
        """
        return self._error_id

    @error_id.setter
    def error_id(self, error_id):
        """Sets the error_id of this Error.

        A positive integer that uniquely identifies the specific error condition that occurred. Your application can use these values as error code identifiers in your customized error-handling algorithms.  # noqa: E501

        :param error_id: The error_id of this Error.  # noqa: E501
        :type: int
        """

        self._error_id = error_id

    @property
    def input_ref_ids(self):
        """Gets the input_ref_ids of this Error.  # noqa: E501

        A list of one or more specific request elements (if any) associated with the error or warning. The format of these strings depends on the request payload format. For JSON, use JSONPath notation.  # noqa: E501

        :return: The input_ref_ids of this Error.  # noqa: E501
        :rtype: list[str]
        """
        return self._input_ref_ids

    @input_ref_ids.setter
    def input_ref_ids(self, input_ref_ids):
        """Sets the input_ref_ids of this Error.

        A list of one or more specific request elements (if any) associated with the error or warning. The format of these strings depends on the request payload format. For JSON, use JSONPath notation.  # noqa: E501

        :param input_ref_ids: The input_ref_ids of this Error.  # noqa: E501
        :type: list[str]
        """

        self._input_ref_ids = input_ref_ids

    @property
    def long_message(self):
        """Gets the long_message of this Error.  # noqa: E501

        An expanded version of the <b>message</b> field. <br /><br /><b>Maximum length:</b> 200 characters  # noqa: E501

        :return: The long_message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._long_message

    @long_message.setter
    def long_message(self, long_message):
        """Sets the long_message of this Error.

        An expanded version of the <b>message</b> field. <br /><br /><b>Maximum length:</b> 200 characters  # noqa: E501

        :param long_message: The long_message of this Error.  # noqa: E501
        :type: str
        """

        self._long_message = long_message

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        A message about the error or warning which is device agnostic and readable by end users and application developers. It explains what the error or warning is, and how to fix it (in a general sense). If applicable, the value is localized to the end user's requested locale. <br /><br /><b>Maximum length:</b> 50 characters  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        A message about the error or warning which is device agnostic and readable by end users and application developers. It explains what the error or warning is, and how to fix it (in a general sense). If applicable, the value is localized to the end user's requested locale. <br /><br /><b>Maximum length:</b> 50 characters  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def output_ref_ids(self):
        """Gets the output_ref_ids of this Error.  # noqa: E501

        A list of one or more specific response elements (if any) associated with the error or warning. The format of these strings depends on the request payload format. For JSON, use JSONPath notation.  # noqa: E501

        :return: The output_ref_ids of this Error.  # noqa: E501
        :rtype: list[str]
        """
        return self._output_ref_ids

    @output_ref_ids.setter
    def output_ref_ids(self, output_ref_ids):
        """Sets the output_ref_ids of this Error.

        A list of one or more specific response elements (if any) associated with the error or warning. The format of these strings depends on the request payload format. For JSON, use JSONPath notation.  # noqa: E501

        :param output_ref_ids: The output_ref_ids of this Error.  # noqa: E501
        :type: list[str]
        """

        self._output_ref_ids = output_ref_ids

    @property
    def parameters(self):
        """Gets the parameters of this Error.  # noqa: E501

        Contains a list of name-value pairs that provide additional information concerning this error or warning. Each item in the list is an input parameter that contributed to the error or warning condition.  # noqa: E501

        :return: The parameters of this Error.  # noqa: E501
        :rtype: list[ErrorParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Error.

        Contains a list of name-value pairs that provide additional information concerning this error or warning. Each item in the list is an input parameter that contributed to the error or warning condition.  # noqa: E501

        :param parameters: The parameters of this Error.  # noqa: E501
        :type: list[ErrorParameter]
        """

        self._parameters = parameters

    @property
    def subdomain(self):
        """Gets the subdomain of this Error.  # noqa: E501

        The name of the domain's subsystem or subdivision. For example, <code>fulfillment</code> is a subdomain in the <code>sell</code> domain.  # noqa: E501

        :return: The subdomain of this Error.  # noqa: E501
        :rtype: str
        """
        return self._subdomain

    @subdomain.setter
    def subdomain(self, subdomain):
        """Sets the subdomain of this Error.

        The name of the domain's subsystem or subdivision. For example, <code>fulfillment</code> is a subdomain in the <code>sell</code> domain.  # noqa: E501

        :param subdomain: The subdomain of this Error.  # noqa: E501
        :type: str
        """

        self._subdomain = subdomain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentDispute(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'SimpleAmount',
        'available_choices': 'list[str]',
        'buyer_provided': 'InfoFromBuyer',
        'buyer_username': 'str',
        'closed_date': 'str',
        'evidence': 'list[DisputeEvidence]',
        'evidence_requests': 'list[EvidenceRequest]',
        'line_items': 'list[OrderLineItems]',
        'monetary_transactions': 'list[MonetaryTransaction]',
        'note': 'str',
        'open_date': 'str',
        'order_id': 'str',
        'payment_dispute_id': 'str',
        'payment_dispute_status': 'str',
        'reason': 'str',
        'resolution': 'PaymentDisputeOutcomeDetail',
        'respond_by_date': 'str',
        'return_address': 'ReturnAddress',
        'revision': 'int',
        'seller_response': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'available_choices': 'availableChoices',
        'buyer_provided': 'buyerProvided',
        'buyer_username': 'buyerUsername',
        'closed_date': 'closedDate',
        'evidence': 'evidence',
        'evidence_requests': 'evidenceRequests',
        'line_items': 'lineItems',
        'monetary_transactions': 'monetaryTransactions',
        'note': 'note',
        'open_date': 'openDate',
        'order_id': 'orderId',
        'payment_dispute_id': 'paymentDisputeId',
        'payment_dispute_status': 'paymentDisputeStatus',
        'reason': 'reason',
        'resolution': 'resolution',
        'respond_by_date': 'respondByDate',
        'return_address': 'returnAddress',
        'revision': 'revision',
        'seller_response': 'sellerResponse'
    }

    def __init__(self, amount=None, available_choices=None, buyer_provided=None, buyer_username=None, closed_date=None, evidence=None, evidence_requests=None, line_items=None, monetary_transactions=None, note=None, open_date=None, order_id=None, payment_dispute_id=None, payment_dispute_status=None, reason=None, resolution=None, respond_by_date=None, return_address=None, revision=None, seller_response=None):  # noqa: E501
        """PaymentDispute - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._available_choices = None
        self._buyer_provided = None
        self._buyer_username = None
        self._closed_date = None
        self._evidence = None
        self._evidence_requests = None
        self._line_items = None
        self._monetary_transactions = None
        self._note = None
        self._open_date = None
        self._order_id = None
        self._payment_dispute_id = None
        self._payment_dispute_status = None
        self._reason = None
        self._resolution = None
        self._respond_by_date = None
        self._return_address = None
        self._revision = None
        self._seller_response = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if available_choices is not None:
            self.available_choices = available_choices
        if buyer_provided is not None:
            self.buyer_provided = buyer_provided
        if buyer_username is not None:
            self.buyer_username = buyer_username
        if closed_date is not None:
            self.closed_date = closed_date
        if evidence is not None:
            self.evidence = evidence
        if evidence_requests is not None:
            self.evidence_requests = evidence_requests
        if line_items is not None:
            self.line_items = line_items
        if monetary_transactions is not None:
            self.monetary_transactions = monetary_transactions
        if note is not None:
            self.note = note
        if open_date is not None:
            self.open_date = open_date
        if order_id is not None:
            self.order_id = order_id
        if payment_dispute_id is not None:
            self.payment_dispute_id = payment_dispute_id
        if payment_dispute_status is not None:
            self.payment_dispute_status = payment_dispute_status
        if reason is not None:
            self.reason = reason
        if resolution is not None:
            self.resolution = resolution
        if respond_by_date is not None:
            self.respond_by_date = respond_by_date
        if return_address is not None:
            self.return_address = return_address
        if revision is not None:
            self.revision = revision
        if seller_response is not None:
            self.seller_response = seller_response

    @property
    def amount(self):
        """Gets the amount of this PaymentDispute.  # noqa: E501


        :return: The amount of this PaymentDispute.  # noqa: E501
        :rtype: SimpleAmount
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentDispute.


        :param amount: The amount of this PaymentDispute.  # noqa: E501
        :type: SimpleAmount
        """

        self._amount = amount

    @property
    def available_choices(self):
        """Gets the available_choices of this PaymentDispute.  # noqa: E501

        The value(s) returned in this array indicate the choices that the seller has when responding to the payment dispute. Once the seller has responded to the payment dispute, this field will no longer be shown, and instead, the <strong>sellerResponse</strong> field will show the decision that the seller made.  # noqa: E501

        :return: The available_choices of this PaymentDispute.  # noqa: E501
        :rtype: list[str]
        """
        return self._available_choices

    @available_choices.setter
    def available_choices(self, available_choices):
        """Sets the available_choices of this PaymentDispute.

        The value(s) returned in this array indicate the choices that the seller has when responding to the payment dispute. Once the seller has responded to the payment dispute, this field will no longer be shown, and instead, the <strong>sellerResponse</strong> field will show the decision that the seller made.  # noqa: E501

        :param available_choices: The available_choices of this PaymentDispute.  # noqa: E501
        :type: list[str]
        """

        self._available_choices = available_choices

    @property
    def buyer_provided(self):
        """Gets the buyer_provided of this PaymentDispute.  # noqa: E501


        :return: The buyer_provided of this PaymentDispute.  # noqa: E501
        :rtype: InfoFromBuyer
        """
        return self._buyer_provided

    @buyer_provided.setter
    def buyer_provided(self, buyer_provided):
        """Sets the buyer_provided of this PaymentDispute.


        :param buyer_provided: The buyer_provided of this PaymentDispute.  # noqa: E501
        :type: InfoFromBuyer
        """

        self._buyer_provided = buyer_provided

    @property
    def buyer_username(self):
        """Gets the buyer_username of this PaymentDispute.  # noqa: E501

        This is the eBay user ID of the buyer that initiated the payment dispute.  # noqa: E501

        :return: The buyer_username of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._buyer_username

    @buyer_username.setter
    def buyer_username(self, buyer_username):
        """Sets the buyer_username of this PaymentDispute.

        This is the eBay user ID of the buyer that initiated the payment dispute.  # noqa: E501

        :param buyer_username: The buyer_username of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._buyer_username = buyer_username

    @property
    def closed_date(self):
        """Gets the closed_date of this PaymentDispute.  # noqa: E501

        The timestamp in this field shows the date/time when the payment dispute was closed, so this field is only returned for payment disputes in the <code>CLOSED</code> state.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The closed_date of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._closed_date

    @closed_date.setter
    def closed_date(self, closed_date):
        """Sets the closed_date of this PaymentDispute.

        The timestamp in this field shows the date/time when the payment dispute was closed, so this field is only returned for payment disputes in the <code>CLOSED</code> state.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param closed_date: The closed_date of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._closed_date = closed_date

    @property
    def evidence(self):
        """Gets the evidence of this PaymentDispute.  # noqa: E501

        This container shows any evidence that has been provided by the seller to contest the payment dispute. Evidence may include shipment tracking information, proof of authentication documentation, image(s) to proof that an item is as described, or financial documentation/invoice.<br><br>This container is only returned if the seller has provided at least one document used as evidence against the payment dispute.  # noqa: E501

        :return: The evidence of this PaymentDispute.  # noqa: E501
        :rtype: list[DisputeEvidence]
        """
        return self._evidence

    @evidence.setter
    def evidence(self, evidence):
        """Sets the evidence of this PaymentDispute.

        This container shows any evidence that has been provided by the seller to contest the payment dispute. Evidence may include shipment tracking information, proof of authentication documentation, image(s) to proof that an item is as described, or financial documentation/invoice.<br><br>This container is only returned if the seller has provided at least one document used as evidence against the payment dispute.  # noqa: E501

        :param evidence: The evidence of this PaymentDispute.  # noqa: E501
        :type: list[DisputeEvidence]
        """

        self._evidence = evidence

    @property
    def evidence_requests(self):
        """Gets the evidence_requests of this PaymentDispute.  # noqa: E501

        This container is returned if one or more evidence documents are being requested from the seller.  # noqa: E501

        :return: The evidence_requests of this PaymentDispute.  # noqa: E501
        :rtype: list[EvidenceRequest]
        """
        return self._evidence_requests

    @evidence_requests.setter
    def evidence_requests(self, evidence_requests):
        """Sets the evidence_requests of this PaymentDispute.

        This container is returned if one or more evidence documents are being requested from the seller.  # noqa: E501

        :param evidence_requests: The evidence_requests of this PaymentDispute.  # noqa: E501
        :type: list[EvidenceRequest]
        """

        self._evidence_requests = evidence_requests

    @property
    def line_items(self):
        """Gets the line_items of this PaymentDispute.  # noqa: E501

        This array is used to identify one or more order line items associated with the payment dispute. There will always be at least one <b>itemId</b>/<b>lineItemId</b> pair returned in this array.  # noqa: E501

        :return: The line_items of this PaymentDispute.  # noqa: E501
        :rtype: list[OrderLineItems]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this PaymentDispute.

        This array is used to identify one or more order line items associated with the payment dispute. There will always be at least one <b>itemId</b>/<b>lineItemId</b> pair returned in this array.  # noqa: E501

        :param line_items: The line_items of this PaymentDispute.  # noqa: E501
        :type: list[OrderLineItems]
        """

        self._line_items = line_items

    @property
    def monetary_transactions(self):
        """Gets the monetary_transactions of this PaymentDispute.  # noqa: E501

        This array provide details about one or more monetary transactions that occur as part of a payment dispute. This array is only returned once one or more monetary transacations occur with a payment dispute.  # noqa: E501

        :return: The monetary_transactions of this PaymentDispute.  # noqa: E501
        :rtype: list[MonetaryTransaction]
        """
        return self._monetary_transactions

    @monetary_transactions.setter
    def monetary_transactions(self, monetary_transactions):
        """Sets the monetary_transactions of this PaymentDispute.

        This array provide details about one or more monetary transactions that occur as part of a payment dispute. This array is only returned once one or more monetary transacations occur with a payment dispute.  # noqa: E501

        :param monetary_transactions: The monetary_transactions of this PaymentDispute.  # noqa: E501
        :type: list[MonetaryTransaction]
        """

        self._monetary_transactions = monetary_transactions

    @property
    def note(self):
        """Gets the note of this PaymentDispute.  # noqa: E501

        This field shows information that the seller provides about the dispute, such as the basis for the dispute, any relevant evidence, tracking numbers, and so forth.<br /><br />This field is limited to 1000 characters.  # noqa: E501

        :return: The note of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this PaymentDispute.

        This field shows information that the seller provides about the dispute, such as the basis for the dispute, any relevant evidence, tracking numbers, and so forth.<br /><br />This field is limited to 1000 characters.  # noqa: E501

        :param note: The note of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def open_date(self):
        """Gets the open_date of this PaymentDispute.  # noqa: E501

        The timestamp in this field shows the date/time when the payment dispute was opened. This field is returned for payment disputes in all states.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The open_date of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._open_date

    @open_date.setter
    def open_date(self, open_date):
        """Sets the open_date of this PaymentDispute.

        The timestamp in this field shows the date/time when the payment dispute was opened. This field is returned for payment disputes in all states.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param open_date: The open_date of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._open_date = open_date

    @property
    def order_id(self):
        """Gets the order_id of this PaymentDispute.  # noqa: E501

        This is the unique identifier of the order involved in the payment dispute.  # noqa: E501

        :return: The order_id of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this PaymentDispute.

        This is the unique identifier of the order involved in the payment dispute.  # noqa: E501

        :param order_id: The order_id of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_dispute_id(self):
        """Gets the payment_dispute_id of this PaymentDispute.  # noqa: E501

        This is the unique identifier of the payment dispute. This is the same identifier that is passed in to the call URI. This identifier is automatically created by eBay once the payment dispute comes into the eBay system.  # noqa: E501

        :return: The payment_dispute_id of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._payment_dispute_id

    @payment_dispute_id.setter
    def payment_dispute_id(self, payment_dispute_id):
        """Sets the payment_dispute_id of this PaymentDispute.

        This is the unique identifier of the payment dispute. This is the same identifier that is passed in to the call URI. This identifier is automatically created by eBay once the payment dispute comes into the eBay system.  # noqa: E501

        :param payment_dispute_id: The payment_dispute_id of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._payment_dispute_id = payment_dispute_id

    @property
    def payment_dispute_status(self):
        """Gets the payment_dispute_status of this PaymentDispute.  # noqa: E501

        The enumeration value in this field gives the current status of the payment dispute. The status of a payment dispute partially determines other fields that are returned in the response. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeStateEnum'>eBay API documentation</a>  # noqa: E501

        :return: The payment_dispute_status of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._payment_dispute_status

    @payment_dispute_status.setter
    def payment_dispute_status(self, payment_dispute_status):
        """Sets the payment_dispute_status of this PaymentDispute.

        The enumeration value in this field gives the current status of the payment dispute. The status of a payment dispute partially determines other fields that are returned in the response. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeStateEnum'>eBay API documentation</a>  # noqa: E501

        :param payment_dispute_status: The payment_dispute_status of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._payment_dispute_status = payment_dispute_status

    @property
    def reason(self):
        """Gets the reason of this PaymentDispute.  # noqa: E501

        The enumeration value in this field gives the reason why the buyer initiated the payment dispute. See <strong>DisputeReasonEnum</strong> type for a description of the supported reasons that buyers can give for initiating a payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeReasonEnum'>eBay API documentation</a>  # noqa: E501

        :return: The reason of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this PaymentDispute.

        The enumeration value in this field gives the reason why the buyer initiated the payment dispute. See <strong>DisputeReasonEnum</strong> type for a description of the supported reasons that buyers can give for initiating a payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:DisputeReasonEnum'>eBay API documentation</a>  # noqa: E501

        :param reason: The reason of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def resolution(self):
        """Gets the resolution of this PaymentDispute.  # noqa: E501


        :return: The resolution of this PaymentDispute.  # noqa: E501
        :rtype: PaymentDisputeOutcomeDetail
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """Sets the resolution of this PaymentDispute.


        :param resolution: The resolution of this PaymentDispute.  # noqa: E501
        :type: PaymentDisputeOutcomeDetail
        """

        self._resolution = resolution

    @property
    def respond_by_date(self):
        """Gets the respond_by_date of this PaymentDispute.  # noqa: E501

        The timestamp in this field shows the date/time when the seller must response to a payment dispute, so this field is only returned for payment disputes in the <code>ACTION_NEEDED</code> state. For payment disputes that currently require action by the seller, that same seller should look at the <strong>availableChoices</strong> array to see the available actions.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :return: The respond_by_date of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._respond_by_date

    @respond_by_date.setter
    def respond_by_date(self, respond_by_date):
        """Sets the respond_by_date of this PaymentDispute.

        The timestamp in this field shows the date/time when the seller must response to a payment dispute, so this field is only returned for payment disputes in the <code>ACTION_NEEDED</code> state. For payment disputes that currently require action by the seller, that same seller should look at the <strong>availableChoices</strong> array to see the available actions.<br/><br/>The timestamps returned here use the ISO-8601 24-hour date and time format, and the time zone used is Universal Coordinated Time (UTC), also known as Greenwich Mean Time (GMT), or Zulu. The ISO-8601 format looks like this: <em>yyyy-MM-ddThh:mm.ss.sssZ</em>. An example would be <code>2019-08-04T19:09:02.768Z</code>.  # noqa: E501

        :param respond_by_date: The respond_by_date of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._respond_by_date = respond_by_date

    @property
    def return_address(self):
        """Gets the return_address of this PaymentDispute.  # noqa: E501


        :return: The return_address of this PaymentDispute.  # noqa: E501
        :rtype: ReturnAddress
        """
        return self._return_address

    @return_address.setter
    def return_address(self, return_address):
        """Sets the return_address of this PaymentDispute.


        :param return_address: The return_address of this PaymentDispute.  # noqa: E501
        :type: ReturnAddress
        """

        self._return_address = return_address

    @property
    def revision(self):
        """Gets the revision of this PaymentDispute.  # noqa: E501

        This integer value indicates the revision number of the payment dispute. Each time an action is taken against a payment dispute, this integer value increases by 1.  # noqa: E501

        :return: The revision of this PaymentDispute.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this PaymentDispute.

        This integer value indicates the revision number of the payment dispute. Each time an action is taken against a payment dispute, this integer value increases by 1.  # noqa: E501

        :param revision: The revision of this PaymentDispute.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def seller_response(self):
        """Gets the seller_response of this PaymentDispute.  # noqa: E501

        The enumeration value returned in this field indicates how the seller has responded to the payment dispute. The seller has the option of accepting the payment dispute and agreeing to issue a refund, accepting the payment dispute and agreeing to issue a refund as long as the buyer returns the item, or contesting the payment dispute. This field is returned as soon as the seller makes an initial decision on the payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:SellerResponseEnum'>eBay API documentation</a>  # noqa: E501

        :return: The seller_response of this PaymentDispute.  # noqa: E501
        :rtype: str
        """
        return self._seller_response

    @seller_response.setter
    def seller_response(self, seller_response):
        """Sets the seller_response of this PaymentDispute.

        The enumeration value returned in this field indicates how the seller has responded to the payment dispute. The seller has the option of accepting the payment dispute and agreeing to issue a refund, accepting the payment dispute and agreeing to issue a refund as long as the buyer returns the item, or contesting the payment dispute. This field is returned as soon as the seller makes an initial decision on the payment dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/api:SellerResponseEnum'>eBay API documentation</a>  # noqa: E501

        :param seller_response: The seller_response of this PaymentDispute.  # noqa: E501
        :type: str
        """

        self._seller_response = seller_response

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentDispute, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentDispute):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ...sell_logistics.api.shipment_api import ShipmentApi
from ...sell_logistics.api.shipping_quote_api import ShippingQuoteApi



# coding: utf-8

"""
    Recommendation API

    The <b>Recommendation API</b> returns information that sellers can use to optimize the configuration of their listings on eBay. <br><br>Currently, the API contains a single method, <b>findListingRecommendations</b>. This method provides information that sellers can use to configure Promoted Listings ad campaigns to maximize the visibility of their items in the eBay marketplace.  # noqa: E501

    OpenAPI spec version: 1.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ...sell_recommendation.api_client import ApiClient


class ListingRecommendationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def find_listing_recommendations(self, x_ebay_c_marketplace_id, **kwargs):  # noqa: E501
        """find_listing_recommendations  # noqa: E501

        The find method currently returns information for a single recommendation type (AD) which contains information that sellers can use to configure Promoted Listings ad campaigns. The response from this method includes an array of the seller's listing IDs, where each element in the array contains recommendations related to the associated listing ID. For details on how to use this method, see Using the Recommendation API to help configure campaigns. The AD recommendation type The AD type contains two sets of information: The promoteWithAd indicator The promoteWithAd response field indicates whether or not eBay recommends you place the associated listing in a Promoted Listings ad campaign. The returned value is set to either RECOMMENDED or UNDETERMINED, where RECOMMENDED identifies the listings that will benefit the most from having them included in an ad campaign. The bid percentage Also known as the &quot;ad rate,&quot; the bidPercentage field provides the current trending bid percentage of similarly promoted items in the marketplace. The ad rate is a user-specified value that indicates the level of promotion that eBay applies to the campaign across the marketplace. The value is also used to calculate the Promotion Listings fee, which is assessed to the seller if a Promoted Listings action results in the sale of an item. Configuring the request You can configure a request to review all of a seller's currently active listings, or just a subset of them. All active listings &ndash; If you leave the request body empty, the request targets all the items currently listed by the seller. Here, the response is filtered to contain only the items where promoteWithAd equals RECOMMENDED. In this case, eBay recommends that all the returned listings should be included in a Promoted Listings ad campaign. Selected listing IDs &ndash; If you populate the request body with a set of listingIds, the response contains data for all the specified listing IDs. In this scenario, the response provides you with information on listings where the promoteWithAd can be either RECOMMENDED or UNDETERMINED. The paginated response Because the response can contain many listing IDs, the findListingRecommendations method paginates the response set. You can control size of the returned pages, as well as an offset that dictates where to start the pagination, using query parameters in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_listing_recommendations(x_ebay_c_marketplace_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ebay_c_marketplace_id: Use this header to specify the eBay marketplace where you list the items for which you want to get recommendations. (required)
        :param FindListingRecommendationRequest body:
        :param str filter: Provide a list of key-value pairs to specify the criteria you want to use to filter the response. In the list, separate each filter key from its associated value with a colon (&quot;:&quot;). Currently, the only supported filter value is recommendationTypes and it supports only the (&quot;AD&quot;) type. Follow the recommendationTypes specifier with the filter type(s) enclosed in curly braces (&quot;{ }&quot;), and separate multiple types with commas. Example: filter=recommendationTypes:{AD} Default: recommendationTypes:{AD}
        :param str limit: Use this query parameter to set the maximum number of ads to return on a page from the paginated response. Default: 10 Maximum: 500
        :param str offset: Specifies the number of ads to skip in the result set before returning the first ad in the paginated response. Combine offset with the limit query parameter to control the items returned in the response. For example, if you supply an offset of 0 and a limit of 10, the first page of the response contains the first 10 items from the complete list of items retrieved by the call. If offset is 10 and limit is 20, the first page of the response contains items 11-30 from the complete result set. Default: 0
        :return: PagedListingRecommendationCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_listing_recommendations_with_http_info(x_ebay_c_marketplace_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_listing_recommendations_with_http_info(x_ebay_c_marketplace_id, **kwargs)  # noqa: E501
            return data

    def find_listing_recommendations_with_http_info(self, x_ebay_c_marketplace_id, **kwargs):  # noqa: E501
        """find_listing_recommendations  # noqa: E501

        The find method currently returns information for a single recommendation type (AD) which contains information that sellers can use to configure Promoted Listings ad campaigns. The response from this method includes an array of the seller's listing IDs, where each element in the array contains recommendations related to the associated listing ID. For details on how to use this method, see Using the Recommendation API to help configure campaigns. The AD recommendation type The AD type contains two sets of information: The promoteWithAd indicator The promoteWithAd response field indicates whether or not eBay recommends you place the associated listing in a Promoted Listings ad campaign. The returned value is set to either RECOMMENDED or UNDETERMINED, where RECOMMENDED identifies the listings that will benefit the most from having them included in an ad campaign. The bid percentage Also known as the &quot;ad rate,&quot; the bidPercentage field provides the current trending bid percentage of similarly promoted items in the marketplace. The ad rate is a user-specified value that indicates the level of promotion that eBay applies to the campaign across the marketplace. The value is also used to calculate the Promotion Listings fee, which is assessed to the seller if a Promoted Listings action results in the sale of an item. Configuring the request You can configure a request to review all of a seller's currently active listings, or just a subset of them. All active listings &ndash; If you leave the request body empty, the request targets all the items currently listed by the seller. Here, the response is filtered to contain only the items where promoteWithAd equals RECOMMENDED. In this case, eBay recommends that all the returned listings should be included in a Promoted Listings ad campaign. Selected listing IDs &ndash; If you populate the request body with a set of listingIds, the response contains data for all the specified listing IDs. In this scenario, the response provides you with information on listings where the promoteWithAd can be either RECOMMENDED or UNDETERMINED. The paginated response Because the response can contain many listing IDs, the findListingRecommendations method paginates the response set. You can control size of the returned pages, as well as an offset that dictates where to start the pagination, using query parameters in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_listing_recommendations_with_http_info(x_ebay_c_marketplace_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ebay_c_marketplace_id: Use this header to specify the eBay marketplace where you list the items for which you want to get recommendations. (required)
        :param FindListingRecommendationRequest body:
        :param str filter: Provide a list of key-value pairs to specify the criteria you want to use to filter the response. In the list, separate each filter key from its associated value with a colon (&quot;:&quot;). Currently, the only supported filter value is recommendationTypes and it supports only the (&quot;AD&quot;) type. Follow the recommendationTypes specifier with the filter type(s) enclosed in curly braces (&quot;{ }&quot;), and separate multiple types with commas. Example: filter=recommendationTypes:{AD} Default: recommendationTypes:{AD}
        :param str limit: Use this query parameter to set the maximum number of ads to return on a page from the paginated response. Default: 10 Maximum: 500
        :param str offset: Specifies the number of ads to skip in the result set before returning the first ad in the paginated response. Combine offset with the limit query parameter to control the items returned in the response. For example, if you supply an offset of 0 and a limit of 10, the first page of the response contains the first 10 items from the complete list of items retrieved by the call. If offset is 10 and limit is 20, the first page of the response contains items 11-30 from the complete result set. Default: 0
        :return: PagedListingRecommendationCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ebay_c_marketplace_id', 'body', 'filter', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_listing_recommendations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ebay_c_marketplace_id' is set
        if ('x_ebay_c_marketplace_id' not in params or
                params['x_ebay_c_marketplace_id'] is None):
            raise ValueError("Missing the required parameter `x_ebay_c_marketplace_id` when calling `find_listing_recommendations`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}
        if 'x_ebay_c_marketplace_id' in params:
            header_params['X-EBAY-C-MARKETPLACE-ID'] = params['x_ebay_c_marketplace_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_auth']  # noqa: E501

        return self.api_client.call_api(
            '/find', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedListingRecommendationCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Notification API

    The eBay Notification API enables management of the entire end-to-end eBay notification experience by allowing users to:<ul><li>Browse for supported notification topics and retrieve topic details</li><li>Create, configure, and manage notification destination endpionts</li><li>Configure, manage, and test notification subscriptions</li><li>Process eBay notifications and verify the integrity of the message payload</li></ul>  # noqa: E501

    OpenAPI spec version: v1.2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DestinationSearchResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total': 'int',
        'href': 'str',
        'next': 'str',
        'limit': 'int',
        'destinations': 'list[Destination]'
    }

    attribute_map = {
        'total': 'total',
        'href': 'href',
        'next': 'next',
        'limit': 'limit',
        'destinations': 'destinations'
    }

    def __init__(self, total=None, href=None, next=None, limit=None, destinations=None):  # noqa: E501
        """DestinationSearchResponse - a model defined in Swagger"""  # noqa: E501
        self._total = None
        self._href = None
        self._next = None
        self._limit = None
        self._destinations = None
        self.discriminator = None
        if total is not None:
            self.total = total
        if href is not None:
            self.href = href
        if next is not None:
            self.next = next
        if limit is not None:
            self.limit = limit
        if destinations is not None:
            self.destinations = destinations

    @property
    def total(self):
        """Gets the total of this DestinationSearchResponse.  # noqa: E501

        The total number of matches for the search criteria.  # noqa: E501

        :return: The total of this DestinationSearchResponse.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this DestinationSearchResponse.

        The total number of matches for the search criteria.  # noqa: E501

        :param total: The total of this DestinationSearchResponse.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def href(self):
        """Gets the href of this DestinationSearchResponse.  # noqa: E501

        The path to the call URI that produced the current page of results.  # noqa: E501

        :return: The href of this DestinationSearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this DestinationSearchResponse.

        The path to the call URI that produced the current page of results.  # noqa: E501

        :param href: The href of this DestinationSearchResponse.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def next(self):
        """Gets the next of this DestinationSearchResponse.  # noqa: E501

        The URL to access the next set of results. This field includes a <strong>continuation_token</strong>. No <b>prev</b> field is returned, but this value is persistent during the session so that you can use it to return to the next page.<br><br>This field is not returned if fewer records than specified by the <strong>limit</strong> field are returned.  # noqa: E501

        :return: The next of this DestinationSearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this DestinationSearchResponse.

        The URL to access the next set of results. This field includes a <strong>continuation_token</strong>. No <b>prev</b> field is returned, but this value is persistent during the session so that you can use it to return to the next page.<br><br>This field is not returned if fewer records than specified by the <strong>limit</strong> field are returned.  # noqa: E501

        :param next: The next of this DestinationSearchResponse.  # noqa: E501
        :type: str
        """

        self._next = next

    @property
    def limit(self):
        """Gets the limit of this DestinationSearchResponse.  # noqa: E501

        The number of records to show in the current response.<br /><br /><b>Default:</b> 20  # noqa: E501

        :return: The limit of this DestinationSearchResponse.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this DestinationSearchResponse.

        The number of records to show in the current response.<br /><br /><b>Default:</b> 20  # noqa: E501

        :param limit: The limit of this DestinationSearchResponse.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def destinations(self):
        """Gets the destinations of this DestinationSearchResponse.  # noqa: E501

        An array that contains the destination details.  # noqa: E501

        :return: The destinations of this DestinationSearchResponse.  # noqa: E501
        :rtype: list[Destination]
        """
        return self._destinations

    @destinations.setter
    def destinations(self, destinations):
        """Sets the destinations of this DestinationSearchResponse.

        An array that contains the destination details.  # noqa: E501

        :param destinations: The destinations of this DestinationSearchResponse.  # noqa: E501
        :type: list[Destination]
        """

        self._destinations = destinations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DestinationSearchResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DestinationSearchResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    eBay Finances API

    This API is used to retrieve seller payouts and monetary transaction details related to those payouts.  # noqa: E501

    OpenAPI spec version: v1.15.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TransactionSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'adjustment_amount': 'Amount',
        'adjustment_booking_entry': 'str',
        'adjustment_count': 'int',
        'balance_transfer_amount': 'Amount',
        'balance_transfer_booking_entry': 'str',
        'balance_transfer_count': 'int',
        'credit_amount': 'Amount',
        'credit_booking_entry': 'str',
        'credit_count': 'int',
        'dispute_amount': 'Amount',
        'dispute_booking_entry': 'str',
        'dispute_count': 'int',
        'loan_repayment_amount': 'Amount',
        'loan_repayment_booking_entry': 'str',
        'loan_repayment_count': 'int',
        'non_sale_charge_amount': 'Amount',
        'non_sale_charge_booking_entry': 'str',
        'non_sale_charge_count': 'int',
        'on_hold_amount': 'Amount',
        'on_hold_booking_entry': 'str',
        'on_hold_count': 'int',
        'refund_amount': 'Amount',
        'refund_booking_entry': 'str',
        'refund_count': 'int',
        'shipping_label_amount': 'Amount',
        'shipping_label_booking_entry': 'str',
        'shipping_label_count': 'int',
        'transfer_amount': 'Amount',
        'transfer_booking_entry': 'str',
        'transfer_count': 'int',
        'withdrawal_amount': 'Amount',
        'withdrawal_booking_entry': 'str',
        'withdrawal_count': 'int'
    }

    attribute_map = {
        'adjustment_amount': 'adjustmentAmount',
        'adjustment_booking_entry': 'adjustmentBookingEntry',
        'adjustment_count': 'adjustmentCount',
        'balance_transfer_amount': 'balanceTransferAmount',
        'balance_transfer_booking_entry': 'balanceTransferBookingEntry',
        'balance_transfer_count': 'balanceTransferCount',
        'credit_amount': 'creditAmount',
        'credit_booking_entry': 'creditBookingEntry',
        'credit_count': 'creditCount',
        'dispute_amount': 'disputeAmount',
        'dispute_booking_entry': 'disputeBookingEntry',
        'dispute_count': 'disputeCount',
        'loan_repayment_amount': 'loanRepaymentAmount',
        'loan_repayment_booking_entry': 'loanRepaymentBookingEntry',
        'loan_repayment_count': 'loanRepaymentCount',
        'non_sale_charge_amount': 'nonSaleChargeAmount',
        'non_sale_charge_booking_entry': 'nonSaleChargeBookingEntry',
        'non_sale_charge_count': 'nonSaleChargeCount',
        'on_hold_amount': 'onHoldAmount',
        'on_hold_booking_entry': 'onHoldBookingEntry',
        'on_hold_count': 'onHoldCount',
        'refund_amount': 'refundAmount',
        'refund_booking_entry': 'refundBookingEntry',
        'refund_count': 'refundCount',
        'shipping_label_amount': 'shippingLabelAmount',
        'shipping_label_booking_entry': 'shippingLabelBookingEntry',
        'shipping_label_count': 'shippingLabelCount',
        'transfer_amount': 'transferAmount',
        'transfer_booking_entry': 'transferBookingEntry',
        'transfer_count': 'transferCount',
        'withdrawal_amount': 'withdrawalAmount',
        'withdrawal_booking_entry': 'withdrawalBookingEntry',
        'withdrawal_count': 'withdrawalCount'
    }

    def __init__(self, adjustment_amount=None, adjustment_booking_entry=None, adjustment_count=None, balance_transfer_amount=None, balance_transfer_booking_entry=None, balance_transfer_count=None, credit_amount=None, credit_booking_entry=None, credit_count=None, dispute_amount=None, dispute_booking_entry=None, dispute_count=None, loan_repayment_amount=None, loan_repayment_booking_entry=None, loan_repayment_count=None, non_sale_charge_amount=None, non_sale_charge_booking_entry=None, non_sale_charge_count=None, on_hold_amount=None, on_hold_booking_entry=None, on_hold_count=None, refund_amount=None, refund_booking_entry=None, refund_count=None, shipping_label_amount=None, shipping_label_booking_entry=None, shipping_label_count=None, transfer_amount=None, transfer_booking_entry=None, transfer_count=None, withdrawal_amount=None, withdrawal_booking_entry=None, withdrawal_count=None):  # noqa: E501
        """TransactionSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._adjustment_amount = None
        self._adjustment_booking_entry = None
        self._adjustment_count = None
        self._balance_transfer_amount = None
        self._balance_transfer_booking_entry = None
        self._balance_transfer_count = None
        self._credit_amount = None
        self._credit_booking_entry = None
        self._credit_count = None
        self._dispute_amount = None
        self._dispute_booking_entry = None
        self._dispute_count = None
        self._loan_repayment_amount = None
        self._loan_repayment_booking_entry = None
        self._loan_repayment_count = None
        self._non_sale_charge_amount = None
        self._non_sale_charge_booking_entry = None
        self._non_sale_charge_count = None
        self._on_hold_amount = None
        self._on_hold_booking_entry = None
        self._on_hold_count = None
        self._refund_amount = None
        self._refund_booking_entry = None
        self._refund_count = None
        self._shipping_label_amount = None
        self._shipping_label_booking_entry = None
        self._shipping_label_count = None
        self._transfer_amount = None
        self._transfer_booking_entry = None
        self._transfer_count = None
        self._withdrawal_amount = None
        self._withdrawal_booking_entry = None
        self._withdrawal_count = None
        self.discriminator = None
        if adjustment_amount is not None:
            self.adjustment_amount = adjustment_amount
        if adjustment_booking_entry is not None:
            self.adjustment_booking_entry = adjustment_booking_entry
        if adjustment_count is not None:
            self.adjustment_count = adjustment_count
        if balance_transfer_amount is not None:
            self.balance_transfer_amount = balance_transfer_amount
        if balance_transfer_booking_entry is not None:
            self.balance_transfer_booking_entry = balance_transfer_booking_entry
        if balance_transfer_count is not None:
            self.balance_transfer_count = balance_transfer_count
        if credit_amount is not None:
            self.credit_amount = credit_amount
        if credit_booking_entry is not None:
            self.credit_booking_entry = credit_booking_entry
        if credit_count is not None:
            self.credit_count = credit_count
        if dispute_amount is not None:
            self.dispute_amount = dispute_amount
        if dispute_booking_entry is not None:
            self.dispute_booking_entry = dispute_booking_entry
        if dispute_count is not None:
            self.dispute_count = dispute_count
        if loan_repayment_amount is not None:
            self.loan_repayment_amount = loan_repayment_amount
        if loan_repayment_booking_entry is not None:
            self.loan_repayment_booking_entry = loan_repayment_booking_entry
        if loan_repayment_count is not None:
            self.loan_repayment_count = loan_repayment_count
        if non_sale_charge_amount is not None:
            self.non_sale_charge_amount = non_sale_charge_amount
        if non_sale_charge_booking_entry is not None:
            self.non_sale_charge_booking_entry = non_sale_charge_booking_entry
        if non_sale_charge_count is not None:
            self.non_sale_charge_count = non_sale_charge_count
        if on_hold_amount is not None:
            self.on_hold_amount = on_hold_amount
        if on_hold_booking_entry is not None:
            self.on_hold_booking_entry = on_hold_booking_entry
        if on_hold_count is not None:
            self.on_hold_count = on_hold_count
        if refund_amount is not None:
            self.refund_amount = refund_amount
        if refund_booking_entry is not None:
            self.refund_booking_entry = refund_booking_entry
        if refund_count is not None:
            self.refund_count = refund_count
        if shipping_label_amount is not None:
            self.shipping_label_amount = shipping_label_amount
        if shipping_label_booking_entry is not None:
            self.shipping_label_booking_entry = shipping_label_booking_entry
        if shipping_label_count is not None:
            self.shipping_label_count = shipping_label_count
        if transfer_amount is not None:
            self.transfer_amount = transfer_amount
        if transfer_booking_entry is not None:
            self.transfer_booking_entry = transfer_booking_entry
        if transfer_count is not None:
            self.transfer_count = transfer_count
        if withdrawal_amount is not None:
            self.withdrawal_amount = withdrawal_amount
        if withdrawal_booking_entry is not None:
            self.withdrawal_booking_entry = withdrawal_booking_entry
        if withdrawal_count is not None:
            self.withdrawal_count = withdrawal_count

    @property
    def adjustment_amount(self):
        """Gets the adjustment_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The adjustment_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._adjustment_amount

    @adjustment_amount.setter
    def adjustment_amount(self, adjustment_amount):
        """Sets the adjustment_amount of this TransactionSummaryResponse.


        :param adjustment_amount: The adjustment_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._adjustment_amount = adjustment_amount

    @property
    def adjustment_booking_entry(self):
        """Gets the adjustment_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The credit debit sign indicator for adjustment. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The adjustment_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._adjustment_booking_entry

    @adjustment_booking_entry.setter
    def adjustment_booking_entry(self, adjustment_booking_entry):
        """Sets the adjustment_booking_entry of this TransactionSummaryResponse.

        The credit debit sign indicator for adjustment. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param adjustment_booking_entry: The adjustment_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._adjustment_booking_entry = adjustment_booking_entry

    @property
    def adjustment_count(self):
        """Gets the adjustment_count of this TransactionSummaryResponse.  # noqa: E501

        Total adjustment count for given payee within a specified period.  # noqa: E501

        :return: The adjustment_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._adjustment_count

    @adjustment_count.setter
    def adjustment_count(self, adjustment_count):
        """Sets the adjustment_count of this TransactionSummaryResponse.

        Total adjustment count for given payee within a specified period.  # noqa: E501

        :param adjustment_count: The adjustment_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._adjustment_count = adjustment_count

    @property
    def balance_transfer_amount(self):
        """Gets the balance_transfer_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The balance_transfer_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._balance_transfer_amount

    @balance_transfer_amount.setter
    def balance_transfer_amount(self, balance_transfer_amount):
        """Sets the balance_transfer_amount of this TransactionSummaryResponse.


        :param balance_transfer_amount: The balance_transfer_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._balance_transfer_amount = balance_transfer_amount

    @property
    def balance_transfer_booking_entry(self):
        """Gets the balance_transfer_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The credit debit sign indicator for the balance transfer. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The balance_transfer_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._balance_transfer_booking_entry

    @balance_transfer_booking_entry.setter
    def balance_transfer_booking_entry(self, balance_transfer_booking_entry):
        """Sets the balance_transfer_booking_entry of this TransactionSummaryResponse.

        The credit debit sign indicator for the balance transfer. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param balance_transfer_booking_entry: The balance_transfer_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._balance_transfer_booking_entry = balance_transfer_booking_entry

    @property
    def balance_transfer_count(self):
        """Gets the balance_transfer_count of this TransactionSummaryResponse.  # noqa: E501

        The total balance transfer count for given payee within the specified period.  # noqa: E501

        :return: The balance_transfer_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._balance_transfer_count

    @balance_transfer_count.setter
    def balance_transfer_count(self, balance_transfer_count):
        """Sets the balance_transfer_count of this TransactionSummaryResponse.

        The total balance transfer count for given payee within the specified period.  # noqa: E501

        :param balance_transfer_count: The balance_transfer_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._balance_transfer_count = balance_transfer_count

    @property
    def credit_amount(self):
        """Gets the credit_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The credit_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._credit_amount

    @credit_amount.setter
    def credit_amount(self, credit_amount):
        """Sets the credit_amount of this TransactionSummaryResponse.


        :param credit_amount: The credit_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._credit_amount = credit_amount

    @property
    def credit_booking_entry(self):
        """Gets the credit_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>creditAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>CREDIT</code>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The credit_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._credit_booking_entry

    @credit_booking_entry.setter
    def credit_booking_entry(self, credit_booking_entry):
        """Sets the credit_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>creditAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>CREDIT</code>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param credit_booking_entry: The credit_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._credit_booking_entry = credit_booking_entry

    @property
    def credit_count(self):
        """Gets the credit_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of the seller's sales and/or credits that match the input criteria. <br/><br/><span class=\"tablenote\"><strong>Note:</strong> Unless the <b>transactionType</b> filter is used in the request to retrieve a specific type of monetary transaction (sale, buyer refund, or seller credit), the <b>creditCount</b> and <b>creditAmount</b> fields account for both order sales and seller credits (the count and value is not distinguished between the two monetary transaction types).</span><br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to either <code>REFUND</code>, <code>DISPUTE</code>, or <code>SHIPPING_LABEL</code>.  # noqa: E501

        :return: The credit_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._credit_count

    @credit_count.setter
    def credit_count(self, credit_count):
        """Sets the credit_count of this TransactionSummaryResponse.

        This integer value indicates the total number of the seller's sales and/or credits that match the input criteria. <br/><br/><span class=\"tablenote\"><strong>Note:</strong> Unless the <b>transactionType</b> filter is used in the request to retrieve a specific type of monetary transaction (sale, buyer refund, or seller credit), the <b>creditCount</b> and <b>creditAmount</b> fields account for both order sales and seller credits (the count and value is not distinguished between the two monetary transaction types).</span><br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to either <code>REFUND</code>, <code>DISPUTE</code>, or <code>SHIPPING_LABEL</code>.  # noqa: E501

        :param credit_count: The credit_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._credit_count = credit_count

    @property
    def dispute_amount(self):
        """Gets the dispute_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The dispute_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._dispute_amount

    @dispute_amount.setter
    def dispute_amount(self, dispute_amount):
        """Sets the dispute_amount of this TransactionSummaryResponse.


        :param dispute_amount: The dispute_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._dispute_amount = dispute_amount

    @property
    def dispute_booking_entry(self):
        """Gets the dispute_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>disputeAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code>, but its possible that <code>CREDIT</code> could be returned if the seller contested one or more payment disputes and won the dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The dispute_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._dispute_booking_entry

    @dispute_booking_entry.setter
    def dispute_booking_entry(self, dispute_booking_entry):
        """Sets the dispute_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>disputeAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code>, but its possible that <code>CREDIT</code> could be returned if the seller contested one or more payment disputes and won the dispute. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param dispute_booking_entry: The dispute_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._dispute_booking_entry = dispute_booking_entry

    @property
    def dispute_count(self):
        """Gets the dispute_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of payment disputes that have been initiated by one or more buyers. Only the orders that match the input criteria are considered. The Payment Disputes methods in the Fulfillment API can be used by the seller to retrieve more information about any payment disputes. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>DISPUTE</code>.  # noqa: E501

        :return: The dispute_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._dispute_count

    @dispute_count.setter
    def dispute_count(self, dispute_count):
        """Sets the dispute_count of this TransactionSummaryResponse.

        This integer value indicates the total number of payment disputes that have been initiated by one or more buyers. Only the orders that match the input criteria are considered. The Payment Disputes methods in the Fulfillment API can be used by the seller to retrieve more information about any payment disputes. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>DISPUTE</code>.  # noqa: E501

        :param dispute_count: The dispute_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._dispute_count = dispute_count

    @property
    def loan_repayment_amount(self):
        """Gets the loan_repayment_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The loan_repayment_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._loan_repayment_amount

    @loan_repayment_amount.setter
    def loan_repayment_amount(self, loan_repayment_amount):
        """Sets the loan_repayment_amount of this TransactionSummaryResponse.


        :param loan_repayment_amount: The loan_repayment_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._loan_repayment_amount = loan_repayment_amount

    @property
    def loan_repayment_booking_entry(self):
        """Gets the loan_repayment_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the <code>loanRepaymentAmount</code> is a <code>DEBIT</code> against, or a <code>CREDIT</code> to, the sellers's account.<br/><br/>For most <code>loanRepaymentAmount</code> transactions, <code>loanRepaymentBookingEntry</code> will be <b>DEBIT</b>. However, if a loan repayment transaction is reversed, that transaction will be shown as a <b>CREDIT</b>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The loan_repayment_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._loan_repayment_booking_entry

    @loan_repayment_booking_entry.setter
    def loan_repayment_booking_entry(self, loan_repayment_booking_entry):
        """Sets the loan_repayment_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the <code>loanRepaymentAmount</code> is a <code>DEBIT</code> against, or a <code>CREDIT</code> to, the sellers's account.<br/><br/>For most <code>loanRepaymentAmount</code> transactions, <code>loanRepaymentBookingEntry</code> will be <b>DEBIT</b>. However, if a loan repayment transaction is reversed, that transaction will be shown as a <b>CREDIT</b>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param loan_repayment_booking_entry: The loan_repayment_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._loan_repayment_booking_entry = loan_repayment_booking_entry

    @property
    def loan_repayment_count(self):
        """Gets the loan_repayment_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of <code>LOAN_REPAYMENT</code> transactions (i.e., <code>DEBIT</code> and <code>CREDIT</code>,) that match the input criteria.<br/><br/>This field is generally returned even if it equals <b>0</b>. However it will not be returned if a <code>transactionType</code> filter is used and its value has been set to any enumeration value other than <code>LOAN_REPAYMENT</code>.  # noqa: E501

        :return: The loan_repayment_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._loan_repayment_count

    @loan_repayment_count.setter
    def loan_repayment_count(self, loan_repayment_count):
        """Sets the loan_repayment_count of this TransactionSummaryResponse.

        This integer value indicates the total number of <code>LOAN_REPAYMENT</code> transactions (i.e., <code>DEBIT</code> and <code>CREDIT</code>,) that match the input criteria.<br/><br/>This field is generally returned even if it equals <b>0</b>. However it will not be returned if a <code>transactionType</code> filter is used and its value has been set to any enumeration value other than <code>LOAN_REPAYMENT</code>.  # noqa: E501

        :param loan_repayment_count: The loan_repayment_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._loan_repayment_count = loan_repayment_count

    @property
    def non_sale_charge_amount(self):
        """Gets the non_sale_charge_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The non_sale_charge_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._non_sale_charge_amount

    @non_sale_charge_amount.setter
    def non_sale_charge_amount(self, non_sale_charge_amount):
        """Sets the non_sale_charge_amount of this TransactionSummaryResponse.


        :param non_sale_charge_amount: The non_sale_charge_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._non_sale_charge_amount = non_sale_charge_amount

    @property
    def non_sale_charge_booking_entry(self):
        """Gets the non_sale_charge_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The credit/debit sign indicator for the non-sale charge. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The non_sale_charge_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._non_sale_charge_booking_entry

    @non_sale_charge_booking_entry.setter
    def non_sale_charge_booking_entry(self, non_sale_charge_booking_entry):
        """Sets the non_sale_charge_booking_entry of this TransactionSummaryResponse.

        The credit/debit sign indicator for the non-sale charge. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param non_sale_charge_booking_entry: The non_sale_charge_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._non_sale_charge_booking_entry = non_sale_charge_booking_entry

    @property
    def non_sale_charge_count(self):
        """Gets the non_sale_charge_count of this TransactionSummaryResponse.  # noqa: E501

        The total non-sale charge count for given payee within a specified period.  # noqa: E501

        :return: The non_sale_charge_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._non_sale_charge_count

    @non_sale_charge_count.setter
    def non_sale_charge_count(self, non_sale_charge_count):
        """Sets the non_sale_charge_count of this TransactionSummaryResponse.

        The total non-sale charge count for given payee within a specified period.  # noqa: E501

        :param non_sale_charge_count: The non_sale_charge_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._non_sale_charge_count = non_sale_charge_count

    @property
    def on_hold_amount(self):
        """Gets the on_hold_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The on_hold_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._on_hold_amount

    @on_hold_amount.setter
    def on_hold_amount(self, on_hold_amount):
        """Sets the on_hold_amount of this TransactionSummaryResponse.


        :param on_hold_amount: The on_hold_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._on_hold_amount = on_hold_amount

    @property
    def on_hold_booking_entry(self):
        """Gets the on_hold_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>onHoldAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>CREDIT</code>, since on-hold funds should eventually be released as part of a payout to the seller once the hold is cleared. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The on_hold_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._on_hold_booking_entry

    @on_hold_booking_entry.setter
    def on_hold_booking_entry(self, on_hold_booking_entry):
        """Sets the on_hold_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>onHoldAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>CREDIT</code>, since on-hold funds should eventually be released as part of a payout to the seller once the hold is cleared. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param on_hold_booking_entry: The on_hold_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._on_hold_booking_entry = on_hold_booking_entry

    @property
    def on_hold_count(self):
        """Gets the on_hold_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of order sales where the associated funds are on hold. Only the orders that match the input criteria are considered.<br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionStatus</strong> filter is used, and its value is set to any value other than <code>FUNDS_ON_HOLD</code>.  # noqa: E501

        :return: The on_hold_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._on_hold_count

    @on_hold_count.setter
    def on_hold_count(self, on_hold_count):
        """Sets the on_hold_count of this TransactionSummaryResponse.

        This integer value indicates the total number of order sales where the associated funds are on hold. Only the orders that match the input criteria are considered.<br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionStatus</strong> filter is used, and its value is set to any value other than <code>FUNDS_ON_HOLD</code>.  # noqa: E501

        :param on_hold_count: The on_hold_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._on_hold_count = on_hold_count

    @property
    def refund_amount(self):
        """Gets the refund_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The refund_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, refund_amount):
        """Sets the refund_amount of this TransactionSummaryResponse.


        :param refund_amount: The refund_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._refund_amount = refund_amount

    @property
    def refund_booking_entry(self):
        """Gets the refund_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>refundAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code> since this a refund from the seller to the buyer. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The refund_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._refund_booking_entry

    @refund_booking_entry.setter
    def refund_booking_entry(self, refund_booking_entry):
        """Sets the refund_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>refundAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code> since this a refund from the seller to the buyer. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param refund_booking_entry: The refund_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._refund_booking_entry = refund_booking_entry

    @property
    def refund_count(self):
        """Gets the refund_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of buyer refunds that match the input criteria. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>REFUND</code>.  # noqa: E501

        :return: The refund_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._refund_count

    @refund_count.setter
    def refund_count(self, refund_count):
        """Sets the refund_count of this TransactionSummaryResponse.

        This integer value indicates the total number of buyer refunds that match the input criteria. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>REFUND</code>.  # noqa: E501

        :param refund_count: The refund_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._refund_count = refund_count

    @property
    def shipping_label_amount(self):
        """Gets the shipping_label_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The shipping_label_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._shipping_label_amount

    @shipping_label_amount.setter
    def shipping_label_amount(self, shipping_label_amount):
        """Sets the shipping_label_amount of this TransactionSummaryResponse.


        :param shipping_label_amount: The shipping_label_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._shipping_label_amount = shipping_label_amount

    @property
    def shipping_label_booking_entry(self):
        """Gets the shipping_label_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>shippingLabelAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code>, as eBay will charge the seller when eBay shipping labels are purchased, but it can be <code>CREDIT</code> if the seller was refunded for a shipping label or was possibly overcharged for a shipping label. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The shipping_label_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._shipping_label_booking_entry

    @shipping_label_booking_entry.setter
    def shipping_label_booking_entry(self, shipping_label_booking_entry):
        """Sets the shipping_label_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>shippingLabelAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code>, as eBay will charge the seller when eBay shipping labels are purchased, but it can be <code>CREDIT</code> if the seller was refunded for a shipping label or was possibly overcharged for a shipping label. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param shipping_label_booking_entry: The shipping_label_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._shipping_label_booking_entry = shipping_label_booking_entry

    @property
    def shipping_label_count(self):
        """Gets the shipping_label_count of this TransactionSummaryResponse.  # noqa: E501

        This is the total number of eBay shipping labels purchased by the seller. The count returned here may depend on the specified input criteria.  # noqa: E501

        :return: The shipping_label_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._shipping_label_count

    @shipping_label_count.setter
    def shipping_label_count(self, shipping_label_count):
        """Sets the shipping_label_count of this TransactionSummaryResponse.

        This is the total number of eBay shipping labels purchased by the seller. The count returned here may depend on the specified input criteria.  # noqa: E501

        :param shipping_label_count: The shipping_label_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._shipping_label_count = shipping_label_count

    @property
    def transfer_amount(self):
        """Gets the transfer_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The transfer_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._transfer_amount

    @transfer_amount.setter
    def transfer_amount(self, transfer_amount):
        """Sets the transfer_amount of this TransactionSummaryResponse.


        :param transfer_amount: The transfer_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._transfer_amount = transfer_amount

    @property
    def transfer_booking_entry(self):
        """Gets the transfer_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>transferAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code> since this a seller reimbursement to eBay for buyer refunds. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The transfer_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._transfer_booking_entry

    @transfer_booking_entry.setter
    def transfer_booking_entry(self, transfer_booking_entry):
        """Sets the transfer_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>transferAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code> since this a seller reimbursement to eBay for buyer refunds. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param transfer_booking_entry: The transfer_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._transfer_booking_entry = transfer_booking_entry

    @property
    def transfer_count(self):
        """Gets the transfer_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of buyer refund transfers that match the input criteria. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>TRANSFER</code>.  # noqa: E501

        :return: The transfer_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._transfer_count

    @transfer_count.setter
    def transfer_count(self, transfer_count):
        """Sets the transfer_count of this TransactionSummaryResponse.

        This integer value indicates the total number of buyer refund transfers that match the input criteria. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>TRANSFER</code>.  # noqa: E501

        :param transfer_count: The transfer_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._transfer_count = transfer_count

    @property
    def withdrawal_amount(self):
        """Gets the withdrawal_amount of this TransactionSummaryResponse.  # noqa: E501


        :return: The withdrawal_amount of this TransactionSummaryResponse.  # noqa: E501
        :rtype: Amount
        """
        return self._withdrawal_amount

    @withdrawal_amount.setter
    def withdrawal_amount(self, withdrawal_amount):
        """Sets the withdrawal_amount of this TransactionSummaryResponse.


        :param withdrawal_amount: The withdrawal_amount of this TransactionSummaryResponse.  # noqa: E501
        :type: Amount
        """

        self._withdrawal_amount = withdrawal_amount

    @property
    def withdrawal_booking_entry(self):
        """Gets the withdrawal_booking_entry of this TransactionSummaryResponse.  # noqa: E501

        The enumeration value indicates whether the dollar amount in the <strong>withdrawalAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code> since this transaction involves a debit to the seller's available payout funds. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :return: The withdrawal_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._withdrawal_booking_entry

    @withdrawal_booking_entry.setter
    def withdrawal_booking_entry(self, withdrawal_booking_entry):
        """Sets the withdrawal_booking_entry of this TransactionSummaryResponse.

        The enumeration value indicates whether the dollar amount in the <strong>withdrawalAmount</strong> field is a charge (debit) to the seller or a credit. Typically, the enumeration value returned here will be <code>DEBIT</code> since this transaction involves a debit to the seller's available payout funds. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/finances/types/pay:BookingEntryEnum'>eBay API documentation</a>  # noqa: E501

        :param withdrawal_booking_entry: The withdrawal_booking_entry of this TransactionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._withdrawal_booking_entry = withdrawal_booking_entry

    @property
    def withdrawal_count(self):
        """Gets the withdrawal_count of this TransactionSummaryResponse.  # noqa: E501

        This integer value indicates the total number of on-demand payouts (withdrawals) that match the input criteria. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>WITHDRAWAL</code>.  # noqa: E501

        :return: The withdrawal_count of this TransactionSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._withdrawal_count

    @withdrawal_count.setter
    def withdrawal_count(self, withdrawal_count):
        """Sets the withdrawal_count of this TransactionSummaryResponse.

        This integer value indicates the total number of on-demand payouts (withdrawals) that match the input criteria. <br><br>This field is generally returned, even if <code>0</code>, but it will not be returned if a <strong>transactionType</strong> filter is used, and its value is set to any value other than <code>WITHDRAWAL</code>.  # noqa: E501

        :param withdrawal_count: The withdrawal_count of this TransactionSummaryResponse.  # noqa: E501
        :type: int
        """

        self._withdrawal_count = withdrawal_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TransactionSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Logistics API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />The <b>Logistics API</b> resources offer the following capabilities: <ul><li><b>shipping_quote</b> &ndash; Consolidates into a list a set of live shipping rates, or quotes, from which you can select a rate to ship a package.</li> <li><b>shipment</b> &ndash; Creates a \"shipment\" for the selected shipping rate.</li></ul> Call <b>createShippingQuote</b> to get a list of live shipping rates. The rates returned are all valid for a specific time window and all quoted prices are at eBay-negotiated rates. <br><br>Select one of the live rates and using its associated <b>rateId</b>, create a \"shipment\" for the package by calling <b>createFromShippingQuote</b>. Creating a shipment completes an agreement, and the cost of the base service and any added shipping options are summed into the returned <b>totalShippingCost</b> value. This action also generates a shipping label that you can use to ship the package.  The total cost of the shipment is incurred when the package is shipped using the supplied shipping label.  <p class=\"tablenote\"><b>Important!</b> Sellers must set up a payment method via their eBay account before they can use the methods in this API to create a shipment and the associated shipping label.</p>  # noqa: E501

    OpenAPI spec version: v1_beta.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PhoneNumber(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'phone_number': 'str'
    }

    attribute_map = {
        'phone_number': 'phoneNumber'
    }

    def __init__(self, phone_number=None):  # noqa: E501
        """PhoneNumber - a model defined in Swagger"""  # noqa: E501
        self._phone_number = None
        self.discriminator = None
        if phone_number is not None:
            self.phone_number = phone_number

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumber.  # noqa: E501

        A telephone number.  # noqa: E501

        :return: The phone_number of this PhoneNumber.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumber.

        A telephone number.  # noqa: E501

        :param phone_number: The phone_number of this PhoneNumber.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PhoneNumber, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumber):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
